/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import '../../focus/focus-ring.js';
import '../../ripple/ripple.js';
import { LitElement, nothing, TemplateResult } from 'lit';
/**
 * A chip component.
 */
export declare abstract class Chip extends LitElement {
    disabled: boolean;
    label: string;
    /**
     * The `id` of the action the primary focus ring and ripple are for.
     */
    protected abstract readonly primaryId: string;
    /**
     * Whether or not the primary ripple is disabled (defaults to `disabled`).
     * Some chip actions such as links cannot be disabled.
     */
    protected get rippleDisabled(): boolean;
    protected render(): TemplateResult<1>;
    protected getContainerClasses(): {
        disabled: boolean;
    };
    protected renderContent(): TemplateResult<1>;
    protected abstract renderPrimaryAction(): TemplateResult;
    protected renderTrailingAction?(): TemplateResult | typeof nothing;
    protected renderOutline(): TemplateResult<1>;
    protected renderLeadingIcon(): TemplateResult;
}
