/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
/**
 * Given a list of select options, this function will return an array of
 * SelectOptionRecords that are selected.
 *
 * @return An array of SelectOptionRecords describing the options that are
 * selected.
 */
export function getSelectedItems(items) {
    const selectedItemRecords = [];
    for (let i = 0; i < items.length; i++) {
        const item = items[i];
        if (item.selected) {
            selectedItemRecords.push([item, i]);
        }
    }
    return selectedItemRecords;
}
/**
 * An event fired by a SelectOption to request selection from md-select.
 * Typically fired after `selected` changes from `false` to `true`.
 */
export class RequestSelectionEvent extends Event {
    constructor() {
        super('request-selection', { bubbles: true, composed: true });
    }
}
/**
 * An event fired by a SelectOption to request deselection from md-select.
 * Typically fired after `selected` changes from `true` to `false`.
 */
export class RequestDeselectionEvent extends Event {
    constructor() {
        super('request-deselection', { bubbles: true, composed: true });
    }
}
//# sourceMappingURL=shared.js.map