/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import '../../elevation/elevation.js';
import '../../focus/focus-ring.js';
import '../../ripple/ripple.js';
import { LitElement, PropertyValues } from 'lit';
/**
 * An element that can select items.
 */
export interface Tabs extends HTMLElement {
    selected?: number;
    selectedItem?: Tab;
    previousSelectedItem?: Tab;
}
type Style = '' | 'primary' | 'secondary';
type Orientation = '' | 'vertical';
/**
 * Tab variant can be `primary` or `secondary and can include a space
 * separated `vertical`.
 */
export type Variant = Style | `${Style} ${Orientation}` | `${Orientation} ${Style}`;
/**
 * Tab component.
 */
export declare class Tab extends LitElement {
    static shadowRootOptions: ShadowRootInit;
    /**
     * Styling variant to display, 'primary' or 'secondary' and can also
     * include `vertical`.
     * Defaults to `primary`.
     */
    variant: Variant;
    /**
     * Whether or not the tab is `disabled`.
     */
    disabled: boolean;
    /**
     * Whether or not the tab is `selected`.
     **/
    selected: boolean;
    /**
     * Whether or not the tab is `focusable`.
     */
    focusable: boolean;
    /**
     * Whether or not the icon renders inline with label or stacked vertically.
     */
    inlineIcon: boolean;
    private readonly button;
    /**
     * Selection indicator element.
     */
    readonly indicator: HTMLElement;
    constructor();
    focus(): void;
    blur(): void;
    protected render(): import("lit-html").TemplateResult<1>;
    protected updated(changed: PropertyValues): void;
    private readonly handleActivationClick;
    private get tabs();
    private animateSelected;
    private getKeyframes;
}
export {};
